<?php

include('../../path.php');

require_once(ROOT_CONFIG);



    class rol

    {

        public function insert_rol($Titulo_Rol, $Fecha_Registro, $Fecha_Modifico)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="INSERT INTO rol_appquadrata(Titulo_Rol, Fecha_Registro, Fecha_Modifico) VALUES ('$Titulo_Rol', '$Fecha_Registro', '$Fecha_Modifico') ";

            $conexion->query($consulta);

            $whatsmyid=$conexion->insert_id;

            $conexion->close();

            return $whatsmyid;

        }



        public function get_rol()

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *,  count(*) as numregis FROM rol_appquadrata where Id_Rol !=1 AND Id_Rol!=2 ORDER BY Id_Rol DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_rolpg($inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM rol_appquadrata where Id_Rol !=1 AND Id_Rol!=2 ORDER BY Id_Rol DESC";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_rol($Id_Rol, $Titulo_Rol, $Fecha_Registro, $Fecha_Modifico)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE rol_appquadrata SET Id_Rol='$Id_Rol', Titulo_Rol='$Titulo_Rol', Fecha_Registro='$Fecha_Registro', Fecha_Modifico='$Fecha_Modifico' WHERE Id_Rol = '$Id_Rol'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;

        }



        public function delete_rol($Id_Rol)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="DELETE FROM rol_appquadrata WHERE Id_Rol='$Id_Rol'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;

        }



        //Funciones adicionales.

        public function getorderby_rol($Nombre,$Orderby)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *,  count(*) as numregis FROM rol_appquadrata where Id_Rol !=1 AND Id_Rol!=2 ORDER BY $Nombre $Orderby";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getorderby_rolpg($Nombre,$Orderby,$inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM rol_appquadrata where Id_Rol !=1 AND Id_Rol!=2 ORDER BY $Nombre $Orderby";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getbyid_rol($Id_Rol)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM rol_appquadrata WHERE Id_Rol='$Id_Rol' and Id_Rol !=1 AND Id_Rol!=2 ORDER BY Id_Rol DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_rol($Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT *, count(*) as numregis FROM rol_appquadrata WHERE (Id_Rol LIKE '%$Buscar%' || Titulo_Rol LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Fecha_Modifico LIKE '%$Buscar%') and Id_Rol !=1 AND Id_Rol!=2 ORDER BY Id_Rol DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_rolpg($Buscar,$inicio,$TAMANO_PAGINA)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM rol_appquadrata WHERE (Id_Rol LIKE '%$Buscar%' || Titulo_Rol LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Fecha_Modifico LIKE '%$Buscar%') and Id_Rol !=1 AND Id_Rol!=2 ORDER BY Id_Rol DESC";

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function searchbyparameter_rol($Parametro,$Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM rol_appquadrata WHERE $Parametro LIKE '%$Buscar%' ORDER BY Id_Rol DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }

  

        public function execute_rol($query)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $Array_adapter=$conexion->query($query);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_field_rol($Field,$Value,$Id_Rol)

        {

            $Valueinto=strtoupper($Value);

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE rol_appquadrata SET $Field='$Valueinto' WHERE Id_Rol= '$Id_Rol'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;                          

        }



        public function update_field_front_rol($Field,$Value,$Id_Rol)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE rol_appquadrata SET $Field='$Value' WHERE Id_Rol= '$Id_Rol'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            return $rowaffected;                          

        }



}



?>